@@ -1,5 +1,5 @@
 package ShardedKV::Storage::MySQL;
-$ShardedKV::Storage::MySQL::VERSION = '0.19';
+$ShardedKV::Storage::MySQL::VERSION = '0.20';
 use Moose;
 # ABSTRACT: MySQL storage backend for ShardedKV
 
@@ -135,6 +135,14 @@ has 'reconnect_interval' => (
   default => 1,
 );
 
+
+has 'refresh_mysql_connection_on_error_regex' => (
+  is => 'rw',
+  isa => 'Maybe[Regexp]',
+  lazy => 1,
+  builder => '_make_refresh_mysql_connection_on_error_regex',
+);
+
 # Could be prepared, but that is kind of nasty wrt. reconnects, so let's not go
 # there unless we have to!
 has '_get_query' => (
@@ -167,6 +175,7 @@ has '_number_of_params' => (
 
 sub BUILD {
   $_[0]->_number_of_params;
+  $_[0]->refresh_mysql_connection_on_error_regex;
 };
 
 sub _calc_no_params {
@@ -223,6 +232,14 @@ sub _make_delete_query {
   return $q;
 }
 
+sub _make_refresh_mysql_connection_on_error_regex {
+  my $self = shift;
+  # Does this really need to be /i and can't it just be bounded? Not
+  # changing how it was in the original source because I didn't have
+  # time to check.
+  return qr/(?:MySQL server has gone away|Lost connection to MySQL server during query)/i;
+}
+
 
 sub prepare_table {
   my $self = shift;
@@ -286,6 +303,7 @@ sub _run_sql {
 
   my $iconn;
   my $rv;
+  my $refresh_mysql_connection_on_error_regex = $self->{refresh_mysql_connection_on_error_regex};
   while (1) {
     my $dbh = $self->mysql_connection;
     eval {
@@ -294,7 +312,8 @@ sub _run_sql {
     } or do {
       my $error = $@ || "Zombie Error";
       ++$iconn;
-      if ($error =~ /MySQL server has gone away/i
+      if (defined $refresh_mysql_connection_on_error_regex
+          and $error =~ $refresh_mysql_connection_on_error_regex
           and $iconn <= $self->max_num_reconnect_attempts)
       {
         sleep($self->reconnect_interval * 2 ** ($iconn-2)) if $iconn > 1;
@@ -386,7 +405,7 @@ ShardedKV::Storage::MySQL - MySQL storage backend for ShardedKV
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
@@ -420,7 +439,7 @@ object will invoke the callback whenever it needs to get a NEW mysql
 database handle. This means when:
 
   - first connecting
-  - "MySQL server has gone away" => reconnect
+  - Error matches refresh_mysql_connection_on_error_regex => reconnect
 
 The callback allows users to hook into the connection logic to implement
 things such as connection caching. If you do use connection caching, then
@@ -527,6 +546,15 @@ Default: 1 second
 
 Can also be fractional seconds.
 
+=head2 refresh_mysql_connection_on_error_regex
+
+A regular expression that we'll match MySQL errors against, if it
+matches the error is considered recoverable and we'll refresh the
+connection. Set to C<Undef> to disable this feature.
+
+Default: Matches "MySQL server has gone away" and "Lost connection to
+MySQL server during query" errors. See the source.
+
 =head1 PUBLIC METHODS
 
 =head2 prepare_table
